==> qtjambi-webenginequick-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiWebEngineQuick/QQuickWebEngineProfile_shell.h <==
#ifndef QQUICKWEBENGINEPROFILE_SHELL_H
#define QQUICKWEBENGINEPROFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtWebEngineQuick/qquickwebengineprofile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JavaAPI>
#include <QtWebEngineCore/QWebEngineDownloadRequest>
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtWebEngineCore/qwebenginenotification.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtJambi/RegistryAPI>


class QQuickWebEngineProfile_shell : public QQuickWebEngineProfile, public QtJambiShellInterface
{
public:
    QQuickWebEngineProfile_shell(QObject* parent0 = nullptr);
    ~QQuickWebEngineProfile_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickWebEngineProfile_access : public QQuickWebEngineProfile
{
};

#endif // QQUICKWEBENGINEPROFILE_SHELL_H

==> qtjambi-webenginequick-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiWebEngineQuick/QQuickWebEngineProfile_shell.h <==
#ifndef QQUICKWEBENGINEPROFILE_SHELL_H
#define QQUICKWEBENGINEPROFILE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineQuick/qquickwebengineprofile.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JavaAPI>
#include <QtWebEngineCore/QWebEngineDownloadRequest>
#if __has_include(<QtWebEngineCore/qwebengineclientcertificatestore.h>)
#include <QtWebEngineCore/qwebengineclientcertificatestore.h>
#endif
#include <QtWebEngineCore/qwebenginecookiestore.h>
#include <QtWebEngineCore/qwebenginenotification.h>
#include <QtWebEngineCore/qwebengineurlrequestinterceptor.h>
#include <QtWebEngineCore/qwebengineurlschemehandler.h>
#include <QtJambi/RegistryAPI>


class QQuickWebEngineProfile_shell : public QQuickWebEngineProfile, public QtJambiShellInterface
{
public:
    QQuickWebEngineProfile_shell(QObject* parent0 = nullptr);
    ~QQuickWebEngineProfile_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickWebEngineProfile_mshell;
    friend class QQuickWebEngineProfile_oshell;
};


class QQuickWebEngineProfile_mshell : public QQuickWebEngineProfile_shell
{
public:
    using QQuickWebEngineProfile_shell::QQuickWebEngineProfile_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQuickWebEngineProfile_oshell : public QQuickWebEngineProfile_mshell
{
public:
    using QQuickWebEngineProfile_mshell::QQuickWebEngineProfile_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickWebEngineProfile_access : public QQuickWebEngineProfile
{
};

#endif // QQUICKWEBENGINEPROFILE_SHELL_H
